@@ -21,16 +21,17 @@
 // Copyright (C) 2008 Hugo Mercier <hmercier31@gmail.com>
 // Copyright (C) 2008 Pino Toscano <pino@kde.org>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
-// Copyright (C) 2009-2011, 2013, 2016-2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009-2011, 2013, 2016-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012, 2013 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2012, 2015 Tobias Koenig <tokoe@kdab.com>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Dileep Sankhla <sankhla.dileep96@gmail.com>
-// Copyright (C) 2018 Tobias Deiminger <haxtibal@posteo.de>
+// Copyright (C) 2018, 2019 Tobias Deiminger <haxtibal@posteo.de>
 // Copyright (C) 2018 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Umang Malik <umang99m@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -446,13 +447,12 @@ public:
   bool referencesStream(Ref targetStreamRef);
 
 private:
-  static bool referencesStream(Object *stateObj, Ref targetStreamRef);
+  static bool referencesStream(const Object *stateObj, Ref targetStreamRef);
   void removeStream(Ref refToStream);
-  void removeStateStreams(Object *state);
+  void removeStateStreams(const Object *state);
 
 protected:
   PDFDoc *doc;
-  XRef *xref;                   // the xref table for this PDF file
   Object appearDict;            // Annotation's AP
 };
 
@@ -547,6 +547,7 @@ public:
   void drawCircle(double cx, double cy, double r, bool fill);
   void drawCircleTopLeft(double cx, double cy, double r);
   void drawCircleBottomRight(double cx, double cy, double r);
+  void drawLineEnding(AnnotLineEndingStyle endingStyle, double x, double y, double size, bool fill, const Matrix& m);
   void drawLineEndSquare(double x, double y, double size, bool fill, const Matrix& m);
   void drawLineEndCircle(double x, double y, double size, bool fill, const Matrix& m);
   void drawLineEndDiamond(double x, double y, double size, bool fill, const Matrix& m);
@@ -554,7 +555,8 @@ public:
   void drawLineEndSlash(double x, double y, double size, const Matrix& m);
   void drawFieldBorder(const FormField *field, const AnnotBorder *border, const AnnotAppearanceCharacs *appearCharacs, const PDFRectangle *rect);
   bool drawFormField(const FormField *field, const Form *form, const GfxResources *resources, const GooString *da, const AnnotBorder *border, const AnnotAppearanceCharacs *appearCharacs, const PDFRectangle *rect, const GooString *appearState, XRef *xref, bool *addedDingbatsResource);
-
+  static double lineEndingXShorten(AnnotLineEndingStyle endingStyle, double size);
+  static double lineEndingXExtendBBox(AnnotLineEndingStyle endingStyle, double size);
   void writeString(const GooString &str);
 
   void append(const char *text);
@@ -666,8 +668,8 @@ public:
   // Get the resource dict of the appearance stream
   virtual Object getAppearanceResDict();
 
-  bool match(Ref *refA)
-    { return ref.num == refA->num && ref.gen == refA->gen; }
+  bool match(const Ref *refA) const
+    { return ref == *refA; }
 
   double getXMin();
   double getYMin();
@@ -682,7 +684,7 @@ public:
   virtual void setContents(GooString *new_content);
   void setName(GooString *new_name);
   void setModified(GooString *new_date);
-  void setFlags(Guint new_flags);
+  void setFlags(unsigned int new_flags);
 
   void setBorder(std::unique_ptr<AnnotBorder> &&new_border);
   void setColor(std::unique_ptr<AnnotColor> &&new_color);
@@ -691,7 +693,6 @@ public:
 
   // getters
   PDFDoc *getDoc() const { return doc; }
-  XRef *getXRef() const { return xref; }
   bool getHasRef() const { return hasRef; }
   Ref getRef() const { return ref; }
   AnnotSubtype getType() const { return type; }
@@ -701,7 +702,7 @@ public:
   int getPageNum() const { return page; }
   const GooString *getName() const { return name.get(); }
   const GooString *getModified() const { return modified.get(); }
-  Guint getFlags() const { return flags; }
+  unsigned int getFlags() const { return flags; }
   AnnotAppearance *getAppearStreams() const { return appearStreams.get(); }
   const GooString *getAppearState() const { return appearState.get(); }
   AnnotBorder *getBorder() const { return border.get(); }
@@ -745,7 +746,7 @@ protected:
   Object annotObj;
 
   std::atomic_int refCnt;
-  
+
   // required data
   AnnotSubtype type;                                // Annotation type
   std::unique_ptr<PDFRectangle> rect;               // Rect
@@ -755,7 +756,7 @@ protected:
   std::unique_ptr<GooString> name;                  // NM
   std::unique_ptr<GooString> modified;              // M
   int       page;                                   // P
-  Guint flags;                                      // F (must be a 32 bit unsigned int)
+  unsigned int flags;                                      // F (must be a 32 bit unsigned int)
   std::unique_ptr<AnnotAppearance> appearStreams;   // AP
   Object appearance;                                // a reference to the Form XObject stream
                                                     //   for the normal appearance
@@ -765,7 +766,6 @@ protected:
   Object oc;                                        // OC
 
   PDFDoc *doc;
-  XRef *xref;			// the xref table for this PDF file
   Ref ref;                      // object ref identifying this annotation
   std::unique_ptr<AnnotBorder> border;              // Border, BS
   std::unique_ptr<AnnotColor> color;                // C
@@ -785,7 +785,7 @@ public:
   AnnotPopup(PDFDoc *docA, Object &&dictObject, const Object *obj);
   ~AnnotPopup();
 
-  Object *getParentNF() { return &parent; }
+  bool hasParent() const { return parentRef != Ref::INVALID(); }
   void setParent(Annot *parentA);
   bool getOpen() const { return open; }
   void setOpen(bool openA);
@@ -793,7 +793,7 @@ public:
 protected:
   void initialize(PDFDoc *docA, Dict *dict);
 
-  Object parent; // Parent
+  Ref parentRef; // Parent
   bool open;   // Open
 };
 
@@ -818,6 +818,7 @@ public:
   double getOpacity() const { return opacity; }
   // getRC
   const GooString *getDate() const { return date.get(); }
+  bool isInReplyTo() const { return inReplyTo != Ref::INVALID(); }
   int getInReplyToID() const { return inReplyTo.num; }
   const GooString *getSubject() const { return subject.get(); }
   AnnotMarkupReplyType getReplyTo() const { return replyTo; }
@@ -832,7 +833,7 @@ public:
 protected:
   void removeReferencedObjects() override;
 
-  std::unique_ptr<GooString> label;   // T            (Default autor)
+  std::unique_ptr<GooString> label;   // T            (Default author)
   std::unique_ptr<AnnotPopup> popup;  // Popup
   double opacity;                     // CA           (Default 1.0)
   // RC
@@ -840,7 +841,7 @@ protected:
   Ref inReplyTo;                      // IRT
   std::unique_ptr<GooString> subject; // Subj
   AnnotMarkupReplyType replyTo;       // RT           (Default R)
-  // this object is overrided by the custom intent fields defined in some
+  // this object is overridden by the custom intent fields defined in some
   // annotation types.
   //GooString *intent;                // IT
   AnnotExternalDataType exData;       // ExData
@@ -1002,6 +1003,8 @@ public:
     intentFreeTextTypeWriter  // FreeTextTypeWriter
   };
 
+  static const double undefinedFontPtSize;
+
   AnnotFreeText(PDFDoc *docA, PDFRectangle *rect, const DefaultAppearance &da);
   AnnotFreeText(PDFDoc *docA, Object &&dictObject, const Object *obj);
   ~AnnotFreeText();
@@ -1103,8 +1106,6 @@ protected:
 
   void initialize(PDFDoc *docA, Dict *dict);
   void generateLineAppearance();
-  static double shortenMainSegmentForEnding(AnnotLineEndingStyle endingStyle, double x, double size);
-  static void drawLineEnding(AnnotLineEndingStyle endingStyle, AnnotAppearanceBuilder& appearBuilder, double x, double y, double size, bool fill, const Matrix& m);
 
   // required
   std::unique_ptr<AnnotCoord> coord1;
@@ -1225,7 +1226,7 @@ public:
   ~AnnotPolygon();
 
   void draw(Gfx *gfx, bool printing) override;
-
+  void generatePolyLineAppearance(AnnotAppearanceBuilder* appearBuilder);
   void setType(AnnotSubtype new_type); // typePolygon or typePolyLine
   void setVertices(AnnotPath *path);
   void setStartEndStyle(AnnotLineEndingStyle start, AnnotLineEndingStyle end);
@@ -1409,6 +1410,8 @@ public:
   LinkAction *getFormAdditionalAction(FormAdditionalActionsType type); // The caller should delete the result
   Dict *getParent() { return parent; }
 
+  bool setFormAdditionalAction(FormAdditionalActionsType type, const GooString &js);
+
 private:
 
   void initialize(PDFDoc *docA, Dict *dict);
